@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2009 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "slicerpropertyset.h"
 #include "slicer.h"
@@ -27,36 +15,52 @@
 
 //BEGIN Private classes
 
-struct Pala::SlicerPropertySet::Private
+class Pala::SlicerPropertySetPrivate
 {
-	Pala::Slicer* m_slicer;
+public:
+	explicit SlicerPropertySetPrivate(Pala::Slicer* slicer)
+	    : m_slicer(slicer)
+	{
+	}
+
+	Pala::Slicer* const m_slicer;
 };
 
-struct Pala::SimpleGridPropertySet::Private {};
+class Pala::SimpleGridPropertySetPrivate : public Pala::SlicerPropertySetPrivate
+{
+public:
+	explicit SimpleGridPropertySetPrivate(Pala::Slicer* slicer)
+	    : SlicerPropertySetPrivate(slicer)
+	{
+	}
+};
 
 //END Private classes
 
 //BEGIN Pala::SlicerPropertySet
 
 Pala::SlicerPropertySet::SlicerPropertySet(Pala::Slicer* slicer)
-	: p(new Pala::SlicerPropertySet::Private)
+	: SlicerPropertySet(*new Pala::SlicerPropertySetPrivate(slicer))
 {
-	p->m_slicer = slicer;
 }
 
-Pala::SlicerPropertySet::~SlicerPropertySet()
+Pala::SlicerPropertySet::SlicerPropertySet(SlicerPropertySetPrivate& dd)
+	: d_ptr(&dd)
 {
-	delete p;
 }
 
+Pala::SlicerPropertySet::~SlicerPropertySet() = default;
+
 Pala::Slicer* Pala::SlicerPropertySet::slicer() const
 {
-	return p->m_slicer;
+	Q_D(const SlicerPropertySet);
+	return d->m_slicer;
 }
 
 void Pala::SlicerPropertySet::addPropertyToSlicer(const QByteArray& key, Pala::SlicerProperty* property)
 {
-	p->m_slicer->addProperty(key, property);
+	Q_D(SlicerPropertySet);
+	d->m_slicer->addProperty(key, property);
 }
 
 //END Pala::SlicerPropertySet
@@ -64,8 +68,7 @@ void Pala::SlicerPropertySet::addPropertyToSlicer(const QByteArray& key, Pala::S
 //BEGIN Pala::SimpleGridPropertySet
 
 Pala::SimpleGridPropertySet::SimpleGridPropertySet(Pala::Slicer* slicer)
-	: Pala::SlicerPropertySet(slicer)
-	, p(0)
+	: Pala::SlicerPropertySet(*new SimpleGridPropertySetPrivate(slicer))
 {
 	Pala::IntegerProperty* prop;
 	prop = new Pala::IntegerProperty(i18n("Piece count"));
@@ -79,10 +82,7 @@ Pala::SimpleGridPropertySet::SimpleGridPropertySet(Pala::Slicer* slicer)
 	addPropertyToSlicer("PieceAspect", prop);
 }
 
-Pala::SimpleGridPropertySet::~SimpleGridPropertySet()
-{
-	delete p;
-}
+Pala::SimpleGridPropertySet::~SimpleGridPropertySet() = default;
 
 QSize Pala::SimpleGridPropertySet::pieceCount(Pala::SlicerJob* job) const
 {
